@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
 our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -181,17 +181,15 @@ sub format {
             } elsif (Data::Check::Structure::is_aohos($data, {max=>$max})) {
                 # collect all mentioned fields
                 my @fieldnames;
-                my $hide_unknown_fields;
                 if ($res->[3] && $res->[3]{'table.fields'} &&
                         $res->[3]{'table.hide_unknown_fields'}) {
-                    $hide_unknown_fields = 1;
                     @fieldnames = @{ $res->[3]{'table.fields'} };
                 } else {
                     my %fieldnames;
                     for my $row (@$data) {
                         $fieldnames{$_}++ for keys %$row;
                     }
-                    my @fieldnames = sort keys %fieldnames;
+                    @fieldnames = sort keys %fieldnames;
                 }
                 my $newdata = [];
                 for my $row (@$data) {
@@ -244,7 +242,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.10 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-01-13.
+This document describes version 0.11 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
